#!/bin/bash
# ECSのserviceをアップデートしてデプロイする

set -eu

CLUSTER=
SERVICE=

function usage() {
    cat <<EOM
ecs_deploy.sh
    -c | --cluster               Name of ECS cluster
    -s | --service-name          Name of service to deploy
EOM
    exit 3
}

function parseArg() {
    if [ $# == 0 ]; then usage; fi

    while [[ $# -gt 0 ]]
    do
        key="$1"

        case $key in
            -c|--cluster)
                CLUSTER="$2"
                shift
                ;;
            -s|--service-name)
                SERVICE="$2"
                shift
                ;;
            *)
                usage
                exit 2
            ;;
        esac
        shift
    done

    if [[ -z "${CLUSTER}" ]] || [[ -z "${SERVICE}" ]]; then
        usage
        exit 2
    fi
}

# サービス更新
# $1: クラスター
# $2: サービス
function deploy() {
    local cluster=$1
    local service=$2

    echo "deploy cluster=${cluster} service=${service}"
    # 対象のイメージが起動するようサービスを更新
    aws ecs update-service --force-new-deployment --cluster "${cluster}" --service "${service}"
}

parseArg "$@"
deploy "${CLUSTER}" "${SERVICE}"
